exportPattern("^[[:alpha:]]+")
import(nnet)
import(rpart)
import(e1071)
import(MASS)
import(stats)
importFrom(pROC, roc)
import(caret)
S3method(print, mcca.ccp)
S3method(print, mcca.pdi)
S3method(print, mcca.pdi.var)
S3method(print, mcca.rsq)
S3method(print, mcca.hum)
S3method(plot, mcca.hum)
importFrom("grDevices", "rainbow")
importFrom(utils, getFromNamespace)
